/*
 ## Cypress FX3 Camera Kit Source file (cyfxuvcdscr.c)
 ## ===========================
 ##
 ##  Copyright Cypress Semiconductor Corporation, 2010-2012,
 ##  All Rights Reserved
 ##  UNPUBLISHED, LICENSED SOFTWARE.
 ##
 ##  CONFIDENTIAL AND PROPRIETARY INFORMATION
 ##  WHICH IS THE PROPERTY OF CYPRESS.
 ##
 ##  Use of this file is governed
 ##  by the license agreement included in the file
 ##
 ##     <install>/license/license.txt
 ##
 ##  where <install> is the Cypress software
 ##  installation root directory path.
 ##
 ## ===========================
*/

/*
 * This file contains the USB descriptors for the FX3 HD 720p camera kit
 * application.
 */

#include "common.h"

/* Standard Device Descriptor */
const uint8_t CyFxUSBDeviceDscr[] __attribute__ ((aligned (32))) =
    {
        0x12,                           /* Descriptor Size */
        CY_U3P_USB_DEVICE_DESCR,        /* Device Descriptor Type */
        0x00,0x02,                      /* USB 2.0 */
        0xEF,                           /* Device Class */
        0x02,                           /* Device Sub-class */
        0x01,                           /* Device protocol */
        0x40,                           /* Maxpacket size for EP0 : 64 bytes */
        0xB4,0x04,                      /* Vendor ID */
#if defined(CONFIG_UV950A_WH_HD820U)
        0xF1,0x04,                      /* Product ID */
#elif defined(CONFIG_UV950A_WH_HD812U)
        0xF0,0x04,                      /* Product ID */
//#elif defined(CONFIG_UV950A_HST_X5)
        //0xE6,0x04,
#elif defined(CONFIG_UV950A_612U)
        0xE1,0x04,
#elif defined(CONFIG_UV950A_620U)
        0xE2,0x04,
#elif defined(CONFIG_UV950A_630U)
        0xF3,0x04,                      /* Product ID */
#elif defined(CONFIG_UV950A_MR)
        0xF4,0x04,                      /* Product ID */
#elif defined(CONFIG_UV950A_YHYY)
        0xF5,0x04,                      /* Product ID */
#else
        0xF2,0x04,		                /* Product ID */
#endif
        0x00,0x00,                      /* Device release number */
        0x01,                           /* Manufacture string index */
        0x02,                           /* Product string index */
        0x00,                           /* Serial number string index */
        0x01                            /* Number of configurations */
    };

/* Device Descriptor for SS */
const uint8_t CyFxUSBDeviceDscrSS[] __attribute__ ((aligned (32))) =
    {
        0x12,                           /* Descriptor Size */
        CY_U3P_USB_DEVICE_DESCR,        /* Device Descriptor Type */
        0x10,0x03,                      /* USB 3.0 */
        0xEF,                           /* Device Class */
        0x02,                           /* Device Sub-class */
        0x01,                           /* Device protocol */
        0x09,                           /* Maxpacket size for EP0 : 2^9 Bytes */
        0xB4,0x04,                      /* Vendor ID */
#if defined(CONFIG_UV950A_WH_HD820U)
        0xF8,0x00,                      /* Product ID */
#elif defined(CONFIG_UV950A_WH_HD812U)
        0xF7,0x00,                      /* Product ID */
//#elif defined(CONFIG_UV950A_HST_X5)
        //0xC6,0x00,
#elif defined(CONFIG_UV950A_612U)
        0xC1,0x00,
#elif defined(CONFIG_UV950A_620U)
        0xC2,0x00,
#elif defined(CONFIG_UV950A_630U)
        0xC3,0x00,                      /* Product ID */
#elif defined(CONFIG_UV950A_MR)
        0xC4,0x00,                      /* Product ID */
#elif defined(CONFIG_UV950A_YHYY)
        0xC5,0x00,                      /* Product ID */
#else
        0xF9,0x00,                      /* Product ID */
#endif
        0x00,0x00,                      /* Device release number */
        0x01,                           /* Manufacture string index */
        0x02,                           /* Product string index */
        0x00,                           /* Serial number string index */
        0x01                            /* Number of configurations */
    };

/* Standard Device Qualifier Descriptor */
const uint8_t CyFxUSBDeviceQualDscr[] __attribute__ ((aligned (32))) =
    {
        0x0A,                           /* Descriptor Size */
        CY_U3P_USB_DEVQUAL_DESCR,       /* Device Qualifier Descriptor Type */
        0x00,0x02,                      /* USB 2.0 */
        0xEF,                           /* Device Class */
        0x02,                           /* Device Sub-class */
        0x01,                           /* Device protocol */
        0x40,                           /* Maxpacket size for EP0 : 64 bytes */
        0x01,                           /* Number of configurations */
        0x00                            /* Reserved */
    };

/* Standard Full Speed Configuration Descriptor */
const uint8_t CyFxUSBFSConfigDscr[] __attribute__ ((aligned (32))) =
    {

        /* Configuration Descriptor Type */
        0x09,                           /* Descriptor Size */
        CY_U3P_USB_CONFIG_DESCR,        /* Configuration Descriptor Type */
        0x09,0x00,                      /* Length of this descriptor and all sub descriptors */
        0x00,                           /* Number of interfaces */
        0x01,                           /* Configuration number */
        0x00,                           /* COnfiguration string index */
        0x80,                           /* Config characteristics - Bus powered */
        0x32,                           /* Max power consumption of device (in 2mA unit) : 100mA */
    };

/* Standard High Speed Configuration Descriptor */
const uint8_t CyFxUSBHSConfigDscr[] __attribute__ ((aligned (32))) =
    {

        /* Configuration Descriptor Type */
        0x09,                           /* Descriptor Size */
        CY_U3P_USB_CONFIG_DESCR,        /* Configuration Descriptor Type */
        0xa3,0x01,						/* Length of this descriptor and all sub descriptors */
        0x02,                           /* Number of interfaces */
        0x01,                           /* Configuration number */
        0x00,                           /* COnfiguration string index */
        0x80,                           /* Config characteristics - Bus powered */
        0xFA,                           /* Max power consumption of device (in 2mA unit) : 500mA */

        /* Interface Association Descriptor */
        0x08,                           /* Descriptor Size */
        CY_FX_INTF_ASSN_DSCR_TYPE,      /* Interface Association Descr Type: 11 */
        0x00,                           /* I/f number of first VideoControl i/f */
        0x02,                           /* Number of Video i/f */
        0x0E,                           /* CC_VIDEO : Video i/f class code */
        0x03,                           /* SC_VIDEO_INTERFACE_COLLECTION : Subclass code */
        0x00,                           /* Protocol : Not used */
        0x00,                           /* String desc index for interface */

        /* Standard Video Control Interface Descriptor */
        0x09,                           /* Descriptor size */
        CY_U3P_USB_INTRFC_DESCR,        /* Interface Descriptor type */
        0x00,                           /* Interface number */
        0x00,                           /* Alternate setting number */
        0x01,                           /* Number of end points */
        0x0E,                           /* CC_VIDEO : Interface class */
        0x01,                           /* CC_VIDEOCONTROL : Interface sub class */
        0x00,                           /* Interface protocol code */
        0x00,                           /* Interface descriptor string index */

        /* Class specific VC Interface Header Descriptor */
        0x0D,                           /* Descriptor size */
        0x24,                           /* Class Specific I/f Header Descriptor type */
        0x01,                           /* Descriptor Sub type : VC_HEADER */
        0x00,0x01,                      /* Revision of class spec : 1.0 */
//        0x51,0x00,                      /* Total Size of class specific descriptors (till Output terminal) */
        0x50,0x00,
        0x00,0x6C,0xDC,0x02,            /* Clock frequency : 48MHz(Deprecated) */
        0x01,                           /* Number of streaming interfaces */
        0x01,                           /* Video streaming I/f 1 belongs to VC i/f */

        /* Input (Camera) Terminal Descriptor */
        0x12,                           /* Descriptor size */
        0x24,                           /* Class specific interface desc type */
        0x02,                           /* Input Terminal Descriptor type */
        0x01,                           /* ID of this terminal */
        0x01,0x02,                      /* Camera terminal type */
        0x00,                           /* No association terminal */
        0x00,                           /* String desc index : Not used */
        0x00,0x00,                      /* No optical zoom supported */
        0x00,0x00,                      /* No optical zoom supported */
        0x00,0x00,                      /* No optical zoom supported */
        0x03,                           /* Size of controls field for this terminal : 3 bytes */
                						/*  D0: Scanning Mode
											D1: Auto-Exposure Mode
        									D2: Auto-Exposure Priority
        									D3: Exposure Time (Absolute)
        									D4: Exposure Time (Relative)
        									D5: Focus (Absolute)
        									D6: Focus (Relative)
        									D7: Iris (Absolute)
        									D8: Iris (Relative)
        									D9: Zoom (Absolute)
        									D10: Zoom (Relative)
        									D11: PanTilt (Absolute)
        									D12: PanTilt (Relative)
											D13: Roll (Absolute)
											D14: Roll (Relative)
											D15: Reserved
											D16: Reserved
											D17: Focus, Auto
											D18: Privacy
        									D19..(n*8-1): Reserved, set to zero */
        								/*
        									D9:  Zoom (Absolute)
            								D10: Zoom (Relative)
            								D11: PanTilt (Absolute)
            								D12: PanTilt (Relative)
               			  					only controls field supported */
//        0x00,0x1e,0x00,				/* ptzλλ  */
//        0x00,0x14,0x00, 				/* ptzλ  */
        0x00,0x00,0x00,

        /* Processing Unit Descriptor */
//        0x0d,
        0x0c,                           /* Descriptor size */
        0x24,                           /* Class specific interface desc type */
        0x05,                           /* Processing Unit Descriptor type */
        0x02,                           /* ID of this terminal */
        0x01,                           /* Source ID : 1 : Conencted to input terminal */
        0x00,0x40,                      /* Digital multiplier */
        0x03,                           /* Size of controls field for this terminal : 3 bytes */
        								/* 	D0: Brightness
											D1: Contrast
											D2: Hue
											D3: Saturation
											D4: Sharpness
											D5: Gamma
											D6: White Balance Temperature
											D7: White Balance Component
											D8: Backlight Compensation
											D9: Gain
											D10: Power Line Frequency
											D11: Hue, Auto
											D12: White Balance Temperature, Auto
											D13: White Balance Component, Auto
											D14: Digital Multiplier
											D15: Digital Multiplier Limit
											D16: Analog Video Standard
											D17: Analog Video Lock Status
	 	 	 	 	 	 	 	 	 	 	D18..(n*8-1): Reserved. Set to zero.*/
        0x00,0x00,0x00,
//		0x3f,0x00,0x00,
        								/*	D0: Brightness
											D1: Contrast
											D2: Hue
											D3: Saturation
											D4: Sharpness
											D5: Gamma
											only controls field supported */
        0x00,                           /* String desc index : Not used */
//        0x00,							/* UVC׼Эй涨,ʾPAL,NTSC ʽ  */

        /* Extension Unit Descriptor */
        0x1C,                           /* Descriptor size */
        0x24,                           /* Class specific interface desc type */
        0x06,                           /* Extension Unit Descriptor type */
        0x03,                           /* ID of this terminal */
        0xFF,0xFF,0xFF,0xFF,            /* 16 byte GUID */
        0xFF,0xFF,0xFF,0xFF,
        0xFF,0xFF,0xFF,0xFF,
        0xFF,0xFF,0xFF,0xFF,
        0x00,                           /* Number of controls in this terminal */
        0x01,                           /* Number of input pins in this terminal */
        0x02,                           /* Source ID : 2 : Connected to Proc Unit */
        0x03,                           /* Size of controls field for this terminal : 3 bytes */
        0x00,0x00,0x00,                 /* No controls supported */
        0x00,                           /* String desc index : Not used */

        /* Output Terminal Descriptor */
        0x09,                           /* Descriptor size */
        0x24,                           /* Class specific interface desc type */
        0x03,                           /* Output Terminal Descriptor type */
        0x04,                           /* ID of this terminal */
        0x01,0x01,                      /* USB Streaming terminal type */
        0x00,                           /* No association terminal */
        0x03,                           /* Source ID : 3 : Connected to Extn Unit */
        0x00,                           /* String desc index : Not used */

        /* Video Control Status Interrupt Endpoint Descriptor */
        0x07,                           /* Descriptor size */
        CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint Descriptor Type */
        CY_FX_EP_CONTROL_STATUS,        /* Endpoint address and description */
        CY_U3P_USB_EP_INTR,             /* Interrupt End point Type */
        0x40,0x00,                      /* Max packet size = 64 bytes */
        0x08,                           /* Servicing interval : 8ms */

        /* Class Specific Interrupt Endpoint Descriptor */
        0x05,                           /* Descriptor size */
        0x25,                           /* Class Specific Endpoint Descriptor Type */
        CY_U3P_USB_EP_INTR,             /* End point Sub Type */
        0x40,0x00,                      /* Max packet size = 64 bytes */

        /* Standard Video Streaming Interface Descriptor (Alternate Setting 0) */
        0x09,                           /* Descriptor size */
        CY_U3P_USB_INTRFC_DESCR,        /* Interface Descriptor type */
        0x01,                           /* Interface number */
        0x00,                           /* Alternate setting number */
        0x01,                           /* Number of end points */
        0x0E,                           /* Interface class : CC_VIDEO */
        0x02,                           /* Interface sub class : CC_VIDEOSTREAMING */
        0x00,                           /* Interface protocol code : Undefined */
        0x00,                           /* Interface descriptor string index */

       /* Class-specific Video Streaming Input Header Descriptor */
        0x0E,                           /* Descriptor size */
        0x24,                           /* Class-specific VS I/f Type */
        0x01,                           /* Descriptotor Subtype : Input Header */
        0x01,                           /* 1 format desciptor follows */
        0x29,0x00,                      /* Total size of Class specific VS descr: 41 Bytes */
//        0x1d,0x01,
        CY_FX_EP_BULK_VIDEO,            /* EP address for BULK video data */
        0x00,                           /* No dynamic format change supported */
        0x04,                           /* Output terminal ID : 4 */
        0x01,                           /* Still image capture method 1 supported */
        0x00,                           /* Hardware trigger NOT supported */
        0x00,                           /* Hardware to initiate still image capture NOT supported */
        0x01,                           /* Size of controls field : 1 byte */
        0x00,                           /* D2 : Compression quality supported */


       /* Class specific Uncompressed VS format descriptor */
        0x1B,                           /* Descriptor size */
        0x24,                           /* Class-specific VS I/f Type */
        0x04,                           /* Subtype : uncompressed format I/F */
        0x01,                           /* Format desciptor index (only one format is supported) */
//        0x07,
        0x08,                           /* number of frame descriptor followed */
        0x59,0x55,0x59,0x32,            /* GUID used to identify streaming-encoding format: YUY2  */
        0x00,0x00,0x10,0x00,
        0x80,0x00,0x00,0xAA,
        0x00,0x38,0x9B,0x71,
        0x10,                           /* Number of bits per pixel used to specify color in the decoded video frame. 0 if not applicable: 10 bit per pixel */
        0x01,                           /* Optimum Frame Index for this stream: 1 */
        0x10,                           /* X dimension of the picture aspect ratio: Non-interlaced in progressive scan */
        0x09,                           /* Y dimension of the picture aspect ratio: Non-interlaced in progressive scan*/
        0x00,                           /* Interlace Flags: Progressive scanning, no interlace */
        0x00,                           /* duplication of the video stream restriction: 0 - no restriction */

        //960*540
        /* Class specific Uncompressed VS frame descriptor */
        0x1e,                           /* Descriptor size */
        0x24,                           /* Descriptor type*/
        0x05,                           /* Subtype: uncompressed frame I/F */
        0x05,                           /* Frame Descriptor Index */
        0x01,                           /* Still image capture method 1 supported, fixed frame rate */
        0xc0,0x03,						/* Width in pixel *///960
        0x1c,0x02,						/* Height in pixel *///540
        0x00,0xe0,0xd4,0x0e,  			/* Min bit rate bits/s. */
        0x00,0xe0,0xd4,0x0e,  			/* Max bit rate bits/s. */
        0x00,0xd2,0x0f,0x00,  			/* Maximum video or still frame size in bytes(Deprecated)*////960*540*2
        0x15,0x16,0x05,0x00,   			/* 30fps */
        0x01,
        0x15,0x16,0x05,0x00,			/* 30fps */

		 //720p15
		 /* Class specific Uncompressed VS Frame descriptor */
		0x22,							/* Descriptor size */
		0x24,                           /* Descriptor type*/
		0x05,                           /* Subtype: uncompressed frame I/F */
		0x03,                           /* Frame Descriptor Index */
		0x01,                           /* Still image capture method 1 supported, fixed frame rate */
		0x00,0x05,					    /* Width in pixel *///1280
		0xD0,0x02,  				    /* Height in pixel *///720
		0x00,0x00,0x2f,0x0d,
		0x00,0x00,0x2f,0x0d,
		0x00,0x20,0x1C,0x00,		   	/* Maximum video or still frame size in bytes(Deprecated) *//* 1280*720*2 */
		0x40,0x42,0x0f,0x00,            /* 10fps */
		0x02,                          	/* Frame interval(Frame Rate) types: Only one frame interval supported */
		0x2a,0x2c,0x0a,0x00,		   	/* Shortest Frame Interval *///15fps
		0x40,0x42,0x0f,0x00,            /* 10fps */

        //720*576p50
		 /* Class specific Uncompressed VS frame descriptor */
        0x1e,							/* Descriptor size */
        0x24,                          	/* Descriptor type*/
        0x05,                           /* Subtype: uncompressed frame I/F */
        0x02,                           /* Frame Descriptor Index */
        0x01,                           /* Still image capture method 1 supported, fixed frame rate */
        0xD0,0x02,						/* Width in pixel *///720
        0x40,0x02,					 	/* Height in pixel *///576
        0x00,0x80,0xc6,0x13,  		 	/* Min bit rate bits/s. */
        0x00,0x80,0xc6,0x13, 			/* Max bit rate bits/s. */
        0x00,0xa8,0x0c,0x00, 			/* Maximum video or still frame size in bytes(Deprecated)*///720*576*2
        0x40,0x0d,0x03,0x00,			/* 50fps */
        0x01,
        0x40,0x0d,0x03,0x00,			/* 50fps */

		//720*480P60
		/* Class specific Uncompressed VS frame descriptor */
		0x1e,							/* Descriptor size */
		0x24,                           /* Descriptor type*/
		0x05,                           /* Subtype: uncompressed frame I/F */
		0x01,                           /* Frame Descriptor Index */
		0x01,                           /* Still image capture method 1 supported, fixed frame rate */
		0xD0,0x02,						/* Width in pixel *///720
		0xE0,0x01,				 		/* Height in pixel *///480
		0x00,0x80,0xc6,0x13,  			/* Min bit rate bits/s. */
		0x00,0x80,0xc6,0x13, 			/* Max bit rate bits/s. */
		0x00,0x8c,0x0a,0x00,		 	/* Maximum video or still frame size in bytes(Deprecated)*///720*480*2
		0x0A,0x8B,0x02,0x00,         	/* 60fps */
		0x01,
		0x0A,0x8B,0x02,0x00,         	/* 60fps */

		//640*360
       /* Class specific Uncompressed VS Frame descriptor */
        0x1E,                           /* Descriptor size */
        0x24,                           /* Descriptor type*/
        0x05,                           /* Subtype: uncompressed frame I/F */
        0x04,                           /* Frame Descriptor Index */
        0x01,                           /* Still image capture method 1 supported, fixed frame rate */
        0x80,0x02,                      /* Width in pixel: 320-QVGA *///640
        0x68,0x01,                      /* Height in pixel 240-QVGA *///360
        0x00,0x80,0x97,0x06,            /* Min bit rate bits/s.*/
        0x00,0x80,0x97,0x06,            /* Max bit rate bits/s.*/
        0x00,0x08,0x07,0x00,            /* Maximum video or still frame size in bytes(Deprecated) *///640*360*2
        0x15,0x16,0x05,0x00,			/* 30fps *//* Default Frame Interval */
        0x01,                           /* Frame interval(Frame Rate) types: Only one frame interval supported */
        0x15,0x16,0x05,0x00,			/* 30fps *//* Shortest Frame Interval */

        //640*480p30
        /* Class specific Uncompressed VS frame descriptor */
		0x1e,							/* Descriptor size */
		0x24,                          	/* Descriptor type*/
		0x05,                           /* Subtype: uncompressed frame I/F */
		0x06,                           /* Frame Descriptor Index */
		0x01,                           /* USB CV NO MORE THAN 1 Still image capture method 1 supported, fixed frame rate */
		0x80,0x02,						/* Width in pixel *///640
		0xe0,0x01,					 	/* Height in pixel *///480
		0x00,0x00,0xca,0x08,  		 	/* Min bit rate bits/s. 640*480*16*30*/
		0x00,0x00,0xca,0x08, 			/* Max bit rate bits/s. */
		0x00,0x60,0x09,0x00, 			/* Maximum video or still frame size in bytes(Deprecated)*///640*480*2
		0x15,0x16,0x05,0x00,			/* 30fps */
		0x01,
		0x15,0x16,0x05,0x00,			/* 30fps */

		//352*288p30
		/* Class specific Uncompressed VS frame descriptor */
		0x1e,							/* Descriptor size */
		0x24,                           /* Descriptor type*/
		0x05,                           /* Subtype: uncompressed frame I/F */
		0x07,                           /* Frame Descriptor Index */
		0x01,                           /* USB CV NO MORE THAN 1  Still image capture method 1 supported, fixed frame rate */
		0x60,0x01,						/* Width in pixel *///352
		0x20,0x01,				 		/* Height in pixel *///288
		0x00,0x80,0xe6,0x02,  			/* Min bit rate bits/s. 352*288*16*30*/
		0x00,0x80,0xe6,0x02, 			/* Max bit rate bits/s. */
		0x00,0x18,0x03,0x00,		 	/* Maximum video or still frame size in bytes(Deprecated)*///352*288*2
		0x15,0x16,0x05,0x00,			/* 30fps */
		0x01,
		0x15,0x16,0x05,0x00,			/* 30fps */
#if 1
		//800*600p30
		0x1e,
		0x24,
		0x05,
		0x08,
		0x01,
		0x20,0x03,
		0x58,0x02,
		0x00,0xa0,0xbb,0x0d,
		0x00,0xa0,0xbb,0x0d,
		0x00,0xa6,0x0e,0x00,
		0x15,0x16,0x05,0x00,
		0x01,
		0x15,0x16,0x05,0x00,
#endif//

		/* Endpoint Descriptor for BULK Streaming Video Data */
		0x07,                           /* Descriptor size */
		CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint Descriptor Type */
		CY_FX_EP_BULK_VIDEO,            /* Endpoint address and description */
		CY_U3P_USB_EP_BULK,             /* BULK End point */
		(uint8_t)(512 & 0x00FF),        /* High speed max packet size is always 512 bytes. */
		(uint8_t)((512 & 0xFF00)>>8),
		0x01                            /* Servicing interval for data transfers */

};

/* BOS for SS */

#define CY_FX_BOS_DSCR_TYPE             15
#define CY_FX_DEVICE_CAPB_DSCR_TYPE     16
#define CY_FX_SS_EP_COMPN_DSCR_TYPE     48

/* Device Capability Type Codes */
#define CY_FX_WIRELESS_USB_CAPB_TYPE    1
#define CY_FX_USB2_EXTN_CAPB_TYPE       2
#define CY_FX_SS_USB_CAPB_TYPE          3
#define CY_FX_CONTAINER_ID_CAPBD_TYPE   4

const uint8_t CyFxUSBBOSDscr[] __attribute__ ((aligned (32))) =
{
        0x05,                           /* Descriptor Size */
        CY_FX_BOS_DSCR_TYPE,            /* Device Descriptor Type */
        0x16,0x00,                      /* Length of this descriptor and all sub descriptors */
        0x02,                           /* Number of device capability descriptors */

        /* USB 2.0 Extension */
        0x07,                           /* Descriptor Size */
        CY_FX_DEVICE_CAPB_DSCR_TYPE,    /* Device Capability Type descriptor */
        CY_FX_USB2_EXTN_CAPB_TYPE,      /* USB 2.0 Extension Capability Type */
        0x00,0x00,0x00,0x00,            /* Supported device level features  */

        /* SuperSpeed Device Capability */
        0x0A,                           /* Descriptor Size */
        CY_FX_DEVICE_CAPB_DSCR_TYPE,    /* Device Capability Type descriptor */
        CY_FX_SS_USB_CAPB_TYPE,         /* SuperSpeed Device Capability Type */
        0x00,                           /* Supported device level features  */
        0x0E,0x00,                      /* Speeds Supported by the device : SS, HS and FS */
        0x03,                           /* Functionality support */
        0x00,                           /* U1 Device Exit Latency */
        0x00,0x00                       /* U2 Device Exit Latency */
};

/* Standard Language ID String Descriptor */
const uint8_t CyFxUSBStringLangIDDscr[] __attribute__ ((aligned (32))) =
    {
        0x04,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        0x09,0x04                       /* Language ID supported */
    };

/* Standard Manufacturer String Descriptor */
const uint8_t CyFxUSBManufactureDscr[] __attribute__ ((aligned (32))) =
    {
        0x10,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'C',0x00,
        'y',0x00,
        'p',0x00,
        'r',0x00,
        'e',0x00,
        's',0x00,
        's',0x00
    };

/* Standard Product String Descriptor */
#if defined(CONFIG_UV950A_SR)
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x0E,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'S',0x00,
        'R',0x00,
        '-',0x00,
        'C',0x00,
        '7',0x00,
        'S',0x00
	};
#elif defined(CONFIG_UV950A_WH_HD820U)
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x14,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'W',0x00,
        'H',0x00,
        '-',0x00,
        'H',0x00,
        'D',0x00,
        '8',0x00,
        '2',0x00,
        '0',0x00,
        'U',0x00
	};
#elif defined(CONFIG_UV950A_WH_HD812U)
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x14,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'W',0x00,
        'H',0x00,
        '-',0x00,
        'H',0x00,
        'D',0x00,
        '8',0x00,
        '1',0x00,
        '2',0x00,
        'U',0x00
	};
#elif defined(CONFIG_UV950A_SRC)
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x10,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'S',0x00,
        'R',0x00,
        '-',0x00,
        'C',0x00,
        '1',0x00,
        '0',0x00,
        '1',0x00
	};
#elif defined(CONFIG_UV950A_CAM)
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x0e,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'c',0x00,
        'a',0x00,
        'm',0x00,
        'e',0x00,
        'r',0x00,
        'a',0x00
	};
#elif defined(CONFIG_UV950A_HST_X5)
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x0e,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'H',0x00,
        'S',0x00,
        'T',0x00,
        '-',0x00,
        'X',0x00,
        '5',0x00,
	};
#elif defined(CONFIG_UV950A_612U)
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x16,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'H',0x00,
        'S',0x00,
        'T',0x00,
        '-',0x00,
        'H',0x00,
        'D',0x00,
        '6',0x00,
        '1',0x00,
        '2',0x00,
        'U',0x00
	};
#elif defined(CONFIG_UV950A_620U)
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x16,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'H',0x00,
        'S',0x00,
        'T',0x00,
        '-',0x00,
        'H',0x00,
        'D',0x00,
        '6',0x00,
        '2',0x00,
        '0',0x00,
        'U',0x00
	};
#elif defined(CONFIG_UV950A_630U)
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x16,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'H',0x00,
        'S',0x00,
        'T',0x00,
        '-',0x00,
        'H',0x00,
        'D',0x00,
        '6',0x00,
        '3',0x00,
        '0',0x00,
        'U',0x00
	};
#elif defined(CONFIG_UV950A_MT)
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x08,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'M',0x00,
        '&',0x00,
        'T',0x00
	};
#elif defined(CONFIG_UV950A_HD4)
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x18,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'M',0x00,
        '&',0x00,
        'T',0x00,
        ' ',0x00,
        'H',0x00,
        'D',0x00,
        '4',0x00,
        '-',0x00,
        '1',0x00,
        '0',0x00,
        'X',0x00
	};
#elif defined(CONFIG_UV950A_MR)
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x10,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'M',0x00,
        'i',0x00,
        'n',0x00,
        'r',0x00,
        'r',0x00,
        'a',0x00,
        'y',0x00
	};
#elif defined(CONFIG_UV950A_YHYY)
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x16,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'Y',0x00,
        'H',0x00,
        'Y',0x00,
        'Y',0x00,
        '-',0x00,
        'H',0x00,
        'D',0x00,
        '1',0x00,
        '2',0x00,
        'U',0x00
	};
#else
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
    {
        0x10,                           /* Descriptor Size */
        CY_U3P_USB_STRING_DESCR,        /* Device Descriptor Type */
        'C',0x00,
        'y',0x00,
        't',0x00,
        '-',0x00,
        'F',0x00,
        'X',0x00,
        '4',0x00
	};
#endif//
