/*
 ## Cypress FX3 Camera Kit Source file (cyfxuvcdscr.c)
 ## ===========================
 ##
 ##  Copyright Cypress Semiconductor Corporation, 2010-2012,
 ##  All Rights Reserved
 ##  UNPUBLISHED, LICENSED SOFTWARE.
 ##
 ##  CONFIDENTIAL AND PROPRIETARY INFORMATION
 ##  WHICH IS THE PROPERTY OF CYPRESS.
 ##
 ##  Use of this file is governed
 ##  by the license agreement included in the file
 ##
 ##     <install>/license/license.txt
 ##
 ##  where <install> is the Cypress software
 ##  installation root directory path.
 ##
 ## ===========================
*/

/*
 * This file contains the USB descriptors for the FX3 HD 720p camera kit
 * application.
 */

#include "common.h"

#if defined(CONFIG_UV950A)

/* Super Speed Configuration Descriptor */
const uint8_t CyFxUSBSSConfigDscrVideo[] __attribute__ ((aligned (32))) =
    {

        /* Configuration Descriptor Type */
        0x09,                           /* Descriptor Size */
        CY_U3P_USB_CONFIG_DESCR,        /* Configuration Descriptor Type */
#ifdef CONFIG_UV950A_M
        0x96,0x01,
#else
#ifdef FX3_UVC_1_0_SUPPORT
        0xa5,0x01,                      /* Length of this descriptor and all sub descriptors */
#else
        0xa6,0x01,                      /* Length of this descriptor and all sub descriptors */
#endif
#endif//
        0x02,                           /* Number of interfaces */
        0x01,                           /* Configuration number */
        0x00,                           /* Configuration string index */
        0x80,                           /* Config characteristics - Bus powered */
        0x32,                           /* Max power consumption of device (in 8mA unit) : 400mA */

        /* Interface Association Descriptor */
        0x08,                           /* Descriptor Size */
        CY_FX_INTF_ASSN_DSCR_TYPE,      /* Interface Association Descr Type: 11 */
        0x00,                           /* I/f number of first VideoControl i/f */
        0x02,                           /* Number of Video i/f */
        0x0E,                           /* CC_VIDEO : Video i/f class code */
        0x03,                           /* SC_VIDEO_INTERFACE_COLLECTION : Subclass code */
        0x00,                           /* Protocol : Not used */
        0x00,                           /* String desc index for interface */

        /* Standard Video Control Interface Descriptor */
        0x09,                           /* Descriptor size */
        CY_U3P_USB_INTRFC_DESCR,        /* Interface Descriptor type */
        0x00,                           /* Interface number */
        0x00,                           /* Alternate setting number */
        0x01,                           /* Number of end points */
        0x0E,                           /* CC_VIDEO : Interface class */
        0x01,                           /* CC_VIDEOCONTROL : Interface sub class */
        0x00,                           /* Interface protocol code */
        0x00,                           /* Interface descriptor string index */

        /* Class specific VC Interface Header Descriptor */
        0x0D,                           /* Descriptor size */
        0x24,                           /* Class Specific I/f Header Descriptor type */
        0x01,                           /* Descriptor Sub type : VC_HEADER */
#ifdef FX3_UVC_1_0_SUPPORT
        0x00, 0x01,                     /* Revision of UVC class spec: 1.0 - Legacy version */
        0x50, 0x00,                     /* Total Size of class specific descriptors (till Output terminal) */
#else
        0x10, 0x01,                     /* Revision of UVC class spec: 1.1 - Minimum version required
                                           for USB Compliance. Not supported on Windows XP*/
        0x51, 0x00,                     /* Total Size of class specific descriptors (till Output terminal) */
#endif
        0x00,0x6C,0xDC,0x02,            /* Clock frequency : 48MHz(Deprecated) */
        0x01,                           /* Number of streaming interfaces */
        0x01,                           /* Video streaming I/f 1 belongs to VC i/f */

        /* Input (Camera) Terminal Descriptor */
        0x12,                           /* Descriptor size */
        0x24,                           /* Class specific interface desc type */
        0x02,                           /* Input Terminal Descriptor type */
        0x01,                           /* ID of this terminal */
        0x01,0x02,                      /* Camera terminal type */
        0x00,                           /* No association terminal */
        0x00,                           /* String desc index : Not used */
        0x00,0x00,                      /* No optical zoom supported */
        0x00,0x00,                      /* No optical zoom supported */
        0x00,0x00,                      /* No optical zoom supported */
        0x03,                           /* Size of controls field for this terminal : 3 bytes */
        								/*  D0: Scanning Mode
											D1: Auto-Exposure Mode
											D2: Auto-Exposure Priority
											D3: Exposure Time (Absolute)
											D4: Exposure Time (Relative)
											D5: Focus (Absolute)
											D6: Focus (Relative)
											D7: Iris (Absolute)
											D8: Iris (Relative)
											D9: Zoom (Absolute)
											D10: Zoom (Relative)
											D11: PanTilt (Absolute)
											D12: PanTilt (Relative)
											D13: Roll (Absolute)
											D14: Roll (Relative)
											D15: Reserved
											D16: Reserved
											D17: Focus, Auto
											D18: Privacy
											D19..(n*8-1): Reserved, set to zero */
#ifdef NO_PTZ
        0x00,0x00,0x00,
#else
        0x00,0x1e,0x00, 				/*	D9:  Zoom (Absolute)
    										D10: Zoom (Relative)
    										D11: PanTilt (Absolute)
    										D12: PanTilt (Relative)
       			  							only controls field supported */
#endif

        /* Processing Unit Descriptor */
#ifdef FX3_UVC_1_0_SUPPORT
        0x0C,                           /* Descriptor size */
#else
        0x0D,                           /* Descriptor size */
#endif
        0x24,                           /* Class specific interface desc type */
        0x05,                           /* Processing Unit Descriptor type */
        0x02,                           /* ID of this terminal */
        0x01,                           /* Source ID : 1 : Conencted to input terminal */
        0x00,0x40,                      /* Digital multiplier */
        0x03,                           /* Size of controls field for this terminal : 3 bytes */
        								/* 	D0: Brightness
											D1: Contrast
											D2: Hue
											D3: Saturation
											D4: Sharpness
											D5: Gamma
											D6: White Balance Temperature
											D7: White Balance Component
											D8: Backlight Compensation
											D9: Gain
											D10: Power Line Frequency
											D11: Hue, Auto
											D12: White Balance Temperature, Auto
											D13: White Balance Component, Auto
											D14: Digital Multiplier
											D15: Digital Multiplier Limit
											D16: Analog Video Standard
											D17: Analog Video Lock Status
	 	 	 	 	 	 	 	 	 	 	D18..(n*8-1): Reserved. Set to zero.*/
		0x3F,0x00,0x00,					/*
											D0: Brightness
											D1: Contrast
											D2: Hue
											D3: Saturation
											D4: Sharpness
											D5: Gamma
											only controls field supported */
        0x00,                           /* String desc index : Not used */
#ifndef FX3_UVC_1_0_SUPPORT
        0x00,                           /* Analog Video Standards Supported: None */
#endif

        /* Extension Unit Descriptor */
        0x1C,                           /* Descriptor size */
        0x24,                           /* Class specific interface desc type */
        0x06,                           /* Extension Unit Descriptor type */
        0x03,                           /* ID of this terminal */
        0xFF,0xFF,0xFF,0xFF,            /* 16 byte GUID */
        0xFF,0xFF,0xFF,0xFF,
        0xFF,0xFF,0xFF,0xFF,
        0xFF,0xFF,0xFF,0xFF,
        0x00,                           /* Number of controls in this terminal */
        0x01,                           /* Number of input pins in this terminal */
        0x02,                           /* Source ID : 2 : Connected to Proc Unit */
        0x03,                           /* Size of controls field for this terminal : 3 bytes */
        0x00,0x00,0x00,                 /* No controls supported */
        0x00,                           /* String desc index : Not used */

        /* Output Terminal Descriptor */
        0x09,                           /* Descriptor size */
        0x24,                           /* Class specific interface desc type */
        0x03,                           /* Output Terminal Descriptor type */
        0x04,                           /* ID of this terminal */
        0x01,0x01,                      /* USB Streaming terminal type */
        0x00,                           /* No association terminal */
        0x03,                           /* Source ID : 3 : Connected to Extn Unit */
        0x00,                           /* String desc index : Not used */

        /* Video Control Status Interrupt Endpoint Descriptor */
        0x07,                           /* Descriptor size */
        CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint Descriptor Type */
        CY_FX_EP_CONTROL_STATUS,        /* Endpoint address and description */
        CY_U3P_USB_EP_INTR,             /* Interrupt End point Type */
        0x00,0x04,                      /* Max packet size = 1024 bytes */
        0x01,                           /* Servicing interval */

        /* Super Speed Endpoint Companion Descriptor */
        0x06,                           /* Descriptor size */
        CY_U3P_SS_EP_COMPN_DESCR,       /* SS Endpoint Companion Descriptor Type */
        0x00,                           /* Max no. of packets in a Burst : 1 */
        0x00,                           /* Attribute: N.A. */
        0x00,                           /* Bytes per interval:1024 */
        0x04,

        /* Class Specific Interrupt Endpoint Descriptor */
        0x05,                           /* Descriptor size */
        0x25,                           /* Class Specific Endpoint Descriptor Type */
        CY_U3P_USB_EP_INTR,             /* End point Sub Type */
        0x40,0x00,                      /* Max packet size = 64 bytes */

        /* Standard Video Streaming Interface Descriptor (Alternate Setting 0) */
        0x09,                           /* Descriptor size */
        CY_U3P_USB_INTRFC_DESCR,        /* Interface Descriptor type */
        0x01,                           /* Interface number */
        0x00,                           /* Alternate setting number */
        0x01,                           /* Number of end points */
        0x0E,                           /* Interface class : CC_VIDEO */
        0x02,                           /* Interface sub class : CC_VIDEOSTREAMING */
        0x00,                           /* Interface protocol code : Undefined */
        0x00,                           /* Interface descriptor string index */

       /* Class-specific Video Streaming Input Header Descriptor */
        0x0E,                           /* Descriptor size */
        0x24,                           /* Class-specific VS I/f Type */
        0x01,                           /* Descriptotor Subtype : Input Header */
        0x01,                           /* 1 format desciptor follows */
        0x13,0x01,                      /* Total size of Class specific VS descr */
        CY_FX_EP_BULK_VIDEO,            /* EP address for BULK video data */
        0x00,                           /* No dynamic format change supported */
        0x04,                           /* Output terminal ID : 4 */
        0x01,                           /* Still image capture method 1 supported */
        0x00,                           /* Hardware trigger NOT supported */
        0x00,                           /* Hardware to initiate still image capture NOT supported */
        0x01,                           /* Size of controls field : 1 byte */
        0x00,                           /* D2 : Compression quality supported */


        /* Class specific Uncompressed VS format descriptor */
        0x1B,                           /* Descriptor size */
        0x24,                           /* Class-specific VS I/f Type */
        0x04,                           /* Subtype : uncompressed format I/F */
        0x01,                           /* Format desciptor index */
//        0x06,							/* Number of frame descriptor followed */
        0x07,
        0x59,0x55,0x59,0x32,            /* GUID used to identify streaming-encoding format: YUY2  */
        0x00,0x00,0x10,0x00,
        0x80,0x00,0x00,0xAA,
        0x00,0x38,0x9B,0x71,
        0x10,                           /* Number of bits per pixel */
        0x01,                           /* Optimum Frame Index for this stream: 1 */
        0x10,                           /* X dimension of the picture aspect ratio; Non-interlaced */
        0x09,                           /* Y dimension of the pictuer aspect ratio: Non-interlaced */
        0x00,                           /* Interlace Flags: Progressive scanning, no interlace */
        0x00,                           /* duplication of the video stream restriction: 0 - no restriction */

        //1080p
        /* Class specific Uncompressed VS frame descriptor */
#ifdef CONFIG_UV950A_M
        0x22,
#else
        0x2a,                           /* Descriptor size */
#endif//
        0x24,                           /* Descriptor type*/
        0x05,                           /* Subtype: uncompressed frame I/F */
        0x02,                           /* Frame Descriptor Index */
        0x01,                           /* USB CV NO MORE THAN 1 Still image capture method 1 supported, fixed frame rate */
        0x80,0x07,   					/* Width in pixel */
        0x38,0x04,   					/* Height in pixel */
        0x00,0x00,0xa7,0x76,			/* Min bit rate bits/s. */
        0x00,0x00,0xa7,0x76,			/* Max bit rate bits/s. */
        0x00,0x48,0x3F,0x00,  			/* Maximum video or still frame size in bytes(Deprecated)*///1920*1080*2
        0x15,0x16,0x05,0x00,   			/* 30fps */
#ifdef CONFIG_UV950A_M
        0x02,
        0x15,0x16,0x05,0x00,			/* 30fps */
        0x80,0x1a,0x06,0x00,  			/* 25fps */
#else
        0x04,
        0x0A,0x8B,0x02,0x00,         	/* 60fps */
        0x40,0x0D,0x03,0x00,			/* 50fps */
        0x15,0x16,0x05,0x00,			/* 30fps */
        0x80,0x1a,0x06,0x00,  			/* 25fps */
#endif//

        //720p
        /* Class specific Uncompressed VS frame descriptor */
#ifdef CONFIG_UV950A_M
        0x22,
#else
        0x2a,                           /* Descriptor size */
#endif//
        0x24,                           /* Descriptor type*/
        0x05,                           /* Subtype: uncompressed frame I/F */
        0x01,                           /* Frame Descriptor Index */
        0x01,                           /* USB CV NO MORE THAN 1 Still image capture method 1 supported, fixed frame rate */
        0x00,0x05,  					/* Width in pixel */
        0xD0,0x02,  					/* Height in pixel */
        0x00,0x00,0xbc,0x34,			/* Min bit rate bits/s. */
        0x00,0x00,0xbc,0x34,			/* Max bit rate bits/s. */
        0x00,0x20,0x1c,0x00, 			/* Maximum video or still frame size in bytes(Deprecated)*///1280*720*2
        0x15,0x16,0x05,0x00,			/* 30fps */
#ifdef CONFIG_UV950A_M
        0x02,
        0x15,0x16,0x05,0x00,			/* 30fps */
        0x80,0x1a,0x06,0x00,  			/* 25fps */
#else
        0x04,
        0x0A,0x8B,0x02,0x00,         	/* 60fps */
        0x40,0x0D,0x03,0x00,			/* 50fps */
        0x15,0x16,0x05,0x00,			/* 30fps */
        0x80,0x1a,0x06,0x00,  			/* 25fps */
#endif//

        //640*480p30
		 /* Class specific Uncompressed VS frame descriptor */
        0x1e,							/* Descriptor size */
        0x24,                          	/* Descriptor type*/
        0x05,                           /* Subtype: uncompressed frame I/F */
        0x03,                           /* Frame Descriptor Index */
        0x01,                           /* USB CV NO MORE THAN 1 Still image capture method 1 supported, fixed frame rate */
        0x80,0x02,						/* Width in pixel *///640
        0xe0,0x01,					 	/* Height in pixel *///480
        0x00,0x00,0xca,0x08,  		 	/* Min bit rate bits/s. 640*480*16*30*/
        0x00,0x00,0xca,0x08, 			/* Max bit rate bits/s. */
        0x00,0x60,0x09,0x00, 			/* Maximum video or still frame size in bytes(Deprecated)*///640*480*2
        0x15,0x16,0x05,0x00,			/* 30fps */
        0x01,
        0x15,0x16,0x05,0x00,			/* 30fps */

		//352*288p30
		/* Class specific Uncompressed VS frame descriptor */
		0x1e,							/* Descriptor size */
		0x24,                           /* Descriptor type*/
		0x05,                           /* Subtype: uncompressed frame I/F */
		0x04,                           /* Frame Descriptor Index */
		0x01,                           /* USB CV NO MORE THAN 1  Still image capture method 1 supported, fixed frame rate */
		0x60,0x01,						/* Width in pixel *///352
		0x20,0x01,				 		/* Height in pixel *///288
		0x00,0x80,0xe6,0x02,  			/* Min bit rate bits/s. 352*288*16*30*/
		0x00,0x80,0xe6,0x02, 			/* Max bit rate bits/s. */
		0x00,0x18,0x03,0x00,		 	/* Maximum video or still frame size in bytes(Deprecated)*///352*288*2
		0x15,0x16,0x05,0x00,			/* 30fps */
		0x01,
		0x15,0x16,0x05,0x00,			/* 30fps */

		//640*360
       /* Class specific Uncompressed VS Frame descriptor */
        0x1E,                           /* Descriptor size */
        0x24,                           /* Descriptor type*/
        0x05,                           /* Subtype: uncompressed frame I/F */
        0x05,                           /* Frame Descriptor Index */
        0x01,                           /* USB CV NO MORE THAN  Still image capture method 1 supported, fixed frame rate */
        0x80,0x02,                      /* Width in pixel: 320-QVGA *///640
        0x68,0x01,                      /* Height in pixel 240-QVGA *///360
        0x00,0x80,0x97,0x06,            /* Min bit rate bits/s.*/
        0x00,0x80,0x97,0x06,            /* Max bit rate bits/s.*/
        0x00,0x08,0x07,0x00,            /* Maximum video or still frame size in bytes(Deprecated) *///640*360*2
        0x15,0x16,0x05,0x00,			/* 30fps *//* Default Frame Interval */
        0x01,                           /* Frame interval(Frame Rate) types: Only one frame interval supported */
        0x15,0x16,0x05,0x00,			/* 30fps *//* Shortest Frame Interval */


        //960*540
        /* Class specific Uncompressed VS frame descriptor */
        0x1e,                           /* Descriptor size */
        0x24,                           /* Descriptor type*/
        0x05,                           /* Subtype: uncompressed frame I/F */
        0x06,                           /* Frame Descriptor Index */
        0x01,                           /* USB CV NO MORE THAN 1 Still image capture method 1 supported, fixed frame rate */
        0xc0,0x03,						/* Width in pixel *///960
        0x1c,0x02,						/* Height in pixel *///540
        0x00,0xe0,0xd4,0x0e,  			/* Min bit rate bits/s. */
        0x00,0xe0,0xd4,0x0e,  			/* Max bit rate bits/s. */
        0x00,0xd2,0x0f,0x00,  			/* Maximum video or still frame size in bytes(Deprecated)*////960*540*2
        0x15,0x16,0x05,0x00,   			/* 30fps */
        0x01,
        0x15,0x16,0x05,0x00,			/* 30fps */
#if 1
        //800*600p30
        0x1e,
        0x24,
        0x05,
        0x07,
        0x01,
        0x20,0x03,
        0x58,0x02,
        0x00,0xa0,0xbb,0x0d,
        0x00,0xa0,0xbb,0x0d,
        0x00,0xa6,0x0e,0x00,
        0x15,0x16,0x05,0x00,
        0x01,
        0x15,0x16,0x05,0x00,
#endif//

        /* Endpoint Descriptor for BULK Streaming Video Data */
        0x07,                           /* Descriptor size */
        CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint Descriptor Type */
        CY_FX_EP_BULK_VIDEO,            /* Endpoint address and description */
        CY_U3P_USB_EP_BULK,             /* BULK End point */
        CY_FX_EP_BULK_VIDEO_PKT_SIZE_L, /* EP MaxPcktSize: 1024B */
        CY_FX_EP_BULK_VIDEO_PKT_SIZE_H, /* EP MaxPcktSize: 1024B */
        0x01,                           /* Servicing interval for data transfers */

        /* Super Speed Endpoint Companion Descriptor */
        0x06,                           /* Descriptor size */
        CY_U3P_SS_EP_COMPN_DESCR,       /* SS Endpoint Companion Descriptor Type */
        0x0F,                           /* Max number of packets per burst: 16 */
        0x00,                           /* Attribute: Streams not defined */
        0x00,                           /* No meaning for bulk */
        0x00
};
#endif//CONFIG_UV950A
