#include "common.h"

static uint8_t s_bZoomMove = 0;
static uint8_t s_bPTMove = 0;
static int32_t nPan = 0, nTle = 0;
static int32_t nPan_bak = 0, nTle_bak = 0;

#if defined (CONFIG_PTZ_PAN_MIN)
#if defined (CLEAR_ONE)
static void pantilt_relative(void)
{
	CyBool_t bSendData = CyFalse;
	uint8_t bPanRelative;
	uint8_t bTiltRelative;
    uint8_t bPanSpeed = PAN_SPEED_DEF;
    uint8_t bTiltSpeed = TILI_SPEED_DEF;
	uint16_t readCount = 0;
   	CyU3PReturnStatus_t apiRetStatus = CY_U3P_SUCCESS;

	switch (g_bRequest)
	{
		case CY_FX_USB_UVC_GET_INFO_REQ:
			glEp0Buffer[0] = 3;                /* GET/SET requests supported for this control */
            CyU3PUsbSendEP0Data (1, (uint8_t *)glEp0Buffer);
            break;
		case CY_FX_USB_UVC_GET_CUR_REQ:
			bPanRelative = 0;
            bPanSpeed = 4;
            bTiltRelative = 0;
            bTiltSpeed = 6;
            bSendData = CyTrue;
            break;
		case CY_FX_USB_UVC_GET_MIN_REQ:
			bPanRelative = 0;
            bPanSpeed = 3;
            bTiltRelative = 0;
            bTiltSpeed = 3;
            bSendData = CyTrue;
            break;
		case CY_FX_USB_UVC_GET_MAX_REQ:
			bPanRelative = 0;
            bPanSpeed = 255;
            bTiltRelative = 0;
            bTiltSpeed = 255;
            bSendData = CyTrue;
			break;
		case CY_FX_USB_UVC_GET_RES_REQ:
			bPanRelative = 0;
            bPanSpeed = 1;
            bTiltRelative = 0;
            bTiltSpeed = 1;
            bSendData = CyTrue;
            break;
		case CY_FX_USB_UVC_GET_DEF_REQ:
			bPanRelative = 0;
            bPanSpeed = 3;
            bTiltRelative = 0;
            bTiltSpeed = 3;
            bSendData = CyTrue;
            break;
		case CY_FX_USB_UVC_SET_CUR_REQ:
			apiRetStatus = CyU3PUsbGetEP0Data (CY_FX_UVC_MAX_PROBE_SETTING_ALIGNED, glEp0Buffer, &readCount);
			if(apiRetStatus == CY_U3P_SUCCESS)
			{
				uint8_t bPanMove = 0, bTiltMove = 0;
				uint8_t nPanLeft = 0, nTiltUp = 0;
				uint8_t nPanSpeed = 12, nTiltSpeed = 10;
				DPINFO(3, "%d, glEp0Buffer 0=%X, 1=%X, 2=%X, 3=%X\r\n", __LINE__, glEp0Buffer[0], glEp0Buffer[1], glEp0Buffer[2], glEp0Buffer[3]);
				if(glEp0Buffer[1] == 0xA0)	// Pan Stop
				{
					bPanMove = 0;
				}
				else if(glEp0Buffer[1] == 0x80)	// Pan Right
				{
					bPanMove = 1;
					nPanLeft  = 0;
					//nPanSpeed = glEp0Buffer[1];
				}
				else if(glEp0Buffer[1] == 0x60)	// Pan Left
				{
					bPanMove = 1;
					nPanLeft  = 1;
					//nPanSpeed = glEp0Buffer[1];
				}
				if(glEp0Buffer[3] == 0xA0)	// Tilt Stop
				{
					bTiltMove = 0;
				}
				else if(glEp0Buffer[3] == 0x20)	// Tilt Up
				{
					bTiltMove = 1;
					nTiltUp = 1;
					//nTiltSpeed = glEp0Buffer[3];
				}
				else if(glEp0Buffer[3] == 0x40)	// Tilt Down
				{
					bTiltMove = 1;
					nTiltUp = 0;
					//nTiltSpeed = glEp0Buffer[3];
				}
				if(!bPanMove && !bTiltMove && s_bPTMove)
				{
					uint8_t cmdStop[] = {0xE2, 0x00, 0x81, 0x01, 0x06, 0x01, 0x00, 0x00, 0x03, 0x03, 0xFF};
					datarw_write(cmdStop, sizeof(cmdStop));
					DPINFO(3, "%d, stop all\r\n", __LINE__);
					s_bPTMove = 0;
				}
				if(bPanMove)
				{
					uint8_t cmdPan[] = {0xE2, 0x00, 0x81, 0x01, 0x06, 0x01, 0x00, 0x00, 0x01, 0x03, 0xFF};
					cmdPan[6] = nPanSpeed;
					cmdPan[7] = nTiltSpeed;
					cmdPan[8] = nPanLeft ? 0x01 : 0x02;
					datarw_write(cmdPan, sizeof(cmdPan));
					s_bPTMove = 1;
					DPINFO(3, "%d, pan move dir = %d\r\n", __LINE__, nPanLeft);
				}
				if(bTiltMove)
				{
					uint8_t cmdTilt[] = {0xE2, 0x00, 0x81, 0x01, 0x06, 0x01, 0x00, 0x00, 0x03, 0x01, 0xFF};
					if(bPanMove)
					{
						CyU3PThreadSleep(150);
					}
					cmdTilt[6] = nPanSpeed;
					cmdTilt[7] = nTiltSpeed;
					cmdTilt[9] = nTiltUp ? 0x01 : 0x02;
					datarw_write(cmdTilt, sizeof(cmdTilt));
					s_bPTMove = 1;
					DPINFO(3, "%d, tilt move dir = %d\r\n", __LINE__, nTiltUp);
				}

			}
            break;
		default:
			CyU3PUsbStall (0, CyTrue, CyFalse);
            break;
	}
    if (bSendData)
    {
		/* Send the 8-byte PAN and TILT values back to the USB host. */
        glEp0Buffer[0] = bPanRelative;//CY_U3P_DWORD_GET_BYTE0 (panVal);
        glEp0Buffer[1] = bPanSpeed;//CY_U3P_DWORD_GET_BYTE1 (panVal);
        glEp0Buffer[2] = bTiltRelative;//CY_U3P_DWORD_GET_BYTE2 (panVal);
        glEp0Buffer[3] = bTiltSpeed;//CY_U3P_DWORD_GET_BYTE3 (panVal);
        CyU3PUsbSendEP0Data(g_wLength, (uint8_t *)glEp0Buffer);
	}
}
#else
static void pantilt_relative(void)
{
	CyBool_t bSendData = CyFalse;
	uint8_t bPanRelative;
    uint8_t bPanSpeed = PAN_SPEED_DEF;
    uint8_t bTiltRelative;
    uint8_t bTiltSpeed = TILI_SPEED_DEF;
	uint16_t readCount = 0;
   	CyU3PReturnStatus_t apiRetStatus = CY_U3P_SUCCESS;

	switch (g_bRequest)
	{
		case CY_FX_USB_UVC_GET_INFO_REQ:
			glEp0Buffer[0] = 3;                /* GET/SET requests supported for this control */
            CyU3PUsbSendEP0Data (1, (uint8_t *)glEp0Buffer);
            break;
		case CY_FX_USB_UVC_GET_CUR_REQ:
			bPanRelative = 0;
            bPanSpeed = 4;
            bTiltRelative = 0;
            bTiltSpeed = 6;
            bSendData = CyTrue;
            break;
		case CY_FX_USB_UVC_GET_MIN_REQ:
			bPanRelative = 0;
            bPanSpeed = 3;
            bTiltRelative = 0;
            bTiltSpeed = 3;
            bSendData = CyTrue;
            break;
		case CY_FX_USB_UVC_GET_MAX_REQ:
			bPanRelative = 0;
            bPanSpeed = 255;
            bTiltRelative = 0;
            bTiltSpeed = 255;
            bSendData = CyTrue;
			break;
		case CY_FX_USB_UVC_GET_RES_REQ:
			bPanRelative = 0;
            bPanSpeed = 1;
            bTiltRelative = 0;
            bTiltSpeed = 1;
            bSendData = CyTrue;
            break;
		case CY_FX_USB_UVC_GET_DEF_REQ:
			bPanRelative = 0;
            bPanSpeed = 3;
            bTiltRelative = 0;
            bTiltSpeed = 3;
            bSendData = CyTrue;
            break;
		case CY_FX_USB_UVC_SET_CUR_REQ:
			apiRetStatus = CyU3PUsbGetEP0Data (CY_FX_UVC_MAX_PROBE_SETTING_ALIGNED, glEp0Buffer, &readCount);
			if(apiRetStatus == CY_U3P_SUCCESS)
			{
				uint8_t bPanMove = 0, bTiltMove = 0;
				uint8_t nPanLeft = 0, nTiltUp = 0;
				uint8_t nPanSpeed = 12, nTiltSpeed = 10;
				DPINFO(3, "%d, glEp0Buffer 0=%X, 1=%X, 2=%X, 3=%X\r\n", __LINE__, glEp0Buffer[0], glEp0Buffer[1], glEp0Buffer[2], glEp0Buffer[3]);
				if((glEp0Buffer[0] == 0xA0) || ((glEp0Buffer[0] == 0x00)&&(glEp0Buffer[2] == 0x00)))	// Pan Stop //жʹ֮windowsMAC OS
				{
					bPanMove = 0;
					bTiltMove = 0;
				}
				else if((glEp0Buffer[0] == 0x80) || (glEp0Buffer[0] == 0x01))	// Pan Right //жʹ֮windowsMAC OS
				{
					bPanMove = 1;
					nPanLeft  = 0;
					//nPanSpeed = glEp0Buffer[1];
				}
				else if((glEp0Buffer[0] == 0x60) || (glEp0Buffer[0] == 0xff))	// Pan Left ////жʹ֮windowsMAC OS
				{
					bPanMove = 1;
					nPanLeft  = 1;
					//nPanSpeed = glEp0Buffer[1];
				}
				else if((glEp0Buffer[0] == 0x20) || (glEp0Buffer[2] == 0x01))	// Tilt Up//жʹ֮windowsMAC OS
				{
					bTiltMove = 1;
					nTiltUp = 1;
					//nTiltSpeed = glEp0Buffer[3];
				}
				else if((glEp0Buffer[0] == 0x40) || (glEp0Buffer[2] == 0xff))	// Tilt Down//жʹ֮windowsMAC OS
				{
					bTiltMove = 1;
					nTiltUp = 0;
					//nTiltSpeed = glEp0Buffer[3];
				}
				if(!bPanMove && !bTiltMove && s_bPTMove)
				{
					uint8_t cmdStop[] = {0xE2, 0x00, 0x81, 0x01, 0x06, 0x01, 0x00, 0x00, 0x03, 0x03, 0xFF};
					datarw_write(cmdStop, sizeof(cmdStop));
					DPINFO(3, "%d, stop all\r\n", __LINE__);
					s_bPTMove = 0;
				}
				if(bPanMove)
				{
					uint8_t cmdPan[] = {0xE2, 0x00, 0x81, 0x01, 0x06, 0x01, 0x00, 0x00, 0x01, 0x03, 0xFF};
					cmdPan[6] = nPanSpeed;
					cmdPan[7] = nTiltSpeed;
					cmdPan[8] = nPanLeft ? 0x01 : 0x02;
					datarw_write(cmdPan, sizeof(cmdPan));
					s_bPTMove = 1;
					DPINFO(3, "%d, pan move dir = %d\r\n", __LINE__, nPanLeft);
				}
				if(bTiltMove)
				{
					uint8_t cmdTilt[] = {0xE2, 0x00, 0x81, 0x01, 0x06, 0x01, 0x00, 0x00, 0x03, 0x01, 0xFF};
					if(bPanMove)
					{
						//CyU3PThreadSleep(150);
					}
					cmdTilt[6] = nPanSpeed;
					cmdTilt[7] = nTiltSpeed;
					cmdTilt[9] = nTiltUp ? 0x01 : 0x02;
					datarw_write(cmdTilt, sizeof(cmdTilt));
					s_bPTMove = 1;
					DPINFO(3, "%d, tilt move dir = %d\r\n", __LINE__, nTiltUp);
				}
			}
            break;
		default:
			CyU3PUsbStall (0, CyTrue, CyFalse);
            break;
	}
    if (bSendData)
    {
		/* Send the 8-byte PAN and TILT values back to the USB host. */
        glEp0Buffer[0] = bPanRelative;//CY_U3P_DWORD_GET_BYTE0 (panVal);
        glEp0Buffer[1] = bPanSpeed;//CY_U3P_DWORD_GET_BYTE1 (panVal);
        glEp0Buffer[2] = bTiltRelative;//CY_U3P_DWORD_GET_BYTE2 (panVal);
        glEp0Buffer[3] = bTiltSpeed;//CY_U3P_DWORD_GET_BYTE3 (panVal);
        CyU3PUsbSendEP0Data(g_wLength, (uint8_t *)glEp0Buffer);
	}
}
#endif//CLEAR_ONE
#ifdef DEF_DBG
extern int read_cur_value;
static void pantilt_absolute(void)
{
	uint8_t bSendData = 0;
	int32_t  panVal = 0, tiltVal = 0;
	uint8_t byData[] = {0xE2, 0x00, 0x81, 0x09, 0x04, 0xa8, 0x01, 0xFF};
//	int32_t nPan = 0, nTle = 0;
	CyU3PReturnStatus_t apiRetStatus = CY_U3P_SUCCESS;
	uint16_t readCount = 0;
	switch (g_bRequest)
	{
	case CY_FX_USB_UVC_GET_INFO_REQ:
		glEp0Buffer[0] = 3;                /* GET/SET requests supported for this control */
		CyU3PUsbSendEP0Data(1, (uint8_t *)glEp0Buffer);
		break;
	case CY_FX_USB_UVC_GET_CUR_REQ://8x 09 06 12 FF
#if 1
		if(read_cur_value--)
		{
			datarw_write(byData, sizeof(byData));
		}
		else
		{
			read_cur_value = 0;
		}

		if(datarw_read(g_byReadBuffer, 15, 2, byData[5], byData[6]))
		{
			int16_t PanCur, TleCur;
			PanCur = (g_byReadBuffer[6] << 12)  | (g_byReadBuffer[7] << 8)  | (g_byReadBuffer[8] << 4)  | g_byReadBuffer[9];
			TleCur = (g_byReadBuffer[10] << 12) | (g_byReadBuffer[11] << 8) | (g_byReadBuffer[12] << 4) | g_byReadBuffer[13];


			panVal  = PanCur * 250;//3600 / 14.4;
			tiltVal = TleCur * 250;//3600 / 14.4;

			nPan = PanCur;//#ifdef DEF_DBG
			nTle = TleCur;//#ifdef DEF_DBG

			bSendData = CyTrue;
			DPINFO(3, "%d,  panVal = %d, tiltVal = %d\r\n", __LINE__, panVal, tiltVal);
		}
#if 1
		else
		{
			panVal   = nPan *250;//һη͵ֵͣ϶Ľ,ȻPTһ
			tiltVal  = nTle *250;
			bSendData = CyTrue;
		}
#endif//
#endif//
//		panVal   = nPan *250;//һη͵ֵͣ϶Ľ,ȻPTһ
//		tiltVal  = nTle *250;
//		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_MIN_REQ:
		panVal = CONFIG_PTZ_PAN_MIN;//-170 * 3600;
		tiltVal = CONFIG_PTZ_TILT_MIN;//-30 * 3600;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_MAX_REQ:
		panVal  = CONFIG_PTZ_PAN_MAX;//170 * 3600;
		tiltVal = CONFIG_PTZ_TILT_MAX;//90 * 3600;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_RES_REQ:
		panVal = 1;
		tiltVal = 1;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_DEF_REQ:
		panVal   = 0;
		tiltVal  = 0;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_SET_CUR_REQ:
		{
			uint8_t byData[] = {0xE2, 0x00, 0x81, 0x01, 0x06, 0x02, 0x10, 0x10, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
			apiRetStatus = CyU3PUsbGetEP0Data(CY_FX_UVC_MAX_PROBE_SETTING_ALIGNED, glEp0Buffer, &readCount);
			if(apiRetStatus == CY_U3P_SUCCESS)
			{
				nPan = ((glEp0Buffer[0]) | (glEp0Buffer[1]<<8) |(glEp0Buffer[2]<<16) | (glEp0Buffer[3]<<24));
				nTle = ((glEp0Buffer[4]) | (glEp0Buffer[5]<<8) |(glEp0Buffer[6]<<16) | (glEp0Buffer[7]<<24));
				DPINFO(3, "%d, nPan = %d, nTle = %d, readCount = %d\r\n", __LINE__, nPan, nTle, readCount);
				nPan = ((nPan + 249) / 250);//3600) * 14.4;
				nTle = ((nTle + 249) / 250);//3600) * 14.4;
				if(nPan == nPan_bak && nTle == nTle_bak)
					break;

				nPan_bak = nPan;
				nTle_bak = nTle;

				byData[8]  = (nPan & 0xF000) >> 12;
				byData[9]  = (nPan & 0x0F00) >> 8;
				byData[10] = (nPan & 0x00F0) >> 4;
				byData[11] = (nPan & 0x000F);
				byData[12] = (nTle & 0xF000) >> 12;
				byData[13] = (nTle & 0x0F00) >> 8;
				byData[14] = (nTle & 0x00F0) >> 4;
				byData[15] = (nTle & 0x000F);
				CyU3PThreadSleep(20);
//				CyU3PBusyWait (20);
				datarw_write(byData, sizeof(byData));
//				CyU3PBusyWait (20);
				CyU3PThreadSleep(20);
			}
		}
		break;
	default:
		CyU3PUsbStall (0, CyTrue, CyFalse);
		break;
	}
	if (bSendData)
	{
	 	/* Send the 8-byte PAN and TILT values back to the USB host. */
	    glEp0Buffer[0] = CY_U3P_DWORD_GET_BYTE0 (panVal);
	    glEp0Buffer[1] = CY_U3P_DWORD_GET_BYTE1 (panVal);
	    glEp0Buffer[2] = CY_U3P_DWORD_GET_BYTE2 (panVal);
	    glEp0Buffer[3] = CY_U3P_DWORD_GET_BYTE3 (panVal);
	    glEp0Buffer[4] = CY_U3P_DWORD_GET_BYTE0 (tiltVal);
	    glEp0Buffer[5] = CY_U3P_DWORD_GET_BYTE1 (tiltVal);
	    glEp0Buffer[6] = CY_U3P_DWORD_GET_BYTE2 (tiltVal);
	    glEp0Buffer[7] = CY_U3P_DWORD_GET_BYTE3 (tiltVal);
	    CyU3PUsbSendEP0Data (g_wLength, (uint8_t *)glEp0Buffer);
	}
}
#else
static void pantilt_absolute(void)
{
	uint8_t bSendData = 0;
	int32_t  panVal = 0, tiltVal = 0;
	uint8_t byData[] = {0xE2, 0x00, 0x81, 0x09, 0x04, 0xa8, 0x01, 0xFF};
//	int32_t nPan = 0, nTle = 0;
	CyU3PReturnStatus_t apiRetStatus = CY_U3P_SUCCESS;
	uint16_t readCount = 0;
	switch (g_bRequest)
	{
	case CY_FX_USB_UVC_GET_INFO_REQ:
		glEp0Buffer[0] = 3;                /* GET/SET requests supported for this control */
		CyU3PUsbSendEP0Data(1, (uint8_t *)glEp0Buffer);
		break;
	case CY_FX_USB_UVC_GET_CUR_REQ://8x 09 06 12 FF
#if 1
		datarw_write(byData, sizeof(byData));
		if(datarw_read(g_byReadBuffer, 15, 2, byData[5], byData[6]))
		{
			int16_t PanCur, TleCur;
			PanCur = (g_byReadBuffer[6] << 12)  | (g_byReadBuffer[7] << 8)  | (g_byReadBuffer[8] << 4)  | g_byReadBuffer[9];
			TleCur = (g_byReadBuffer[10] << 12) | (g_byReadBuffer[11] << 8) | (g_byReadBuffer[12] << 4) | g_byReadBuffer[13];

			panVal  = PanCur * 250;//3600 / 14.4;
			tiltVal = TleCur * 250;//3600 / 14.4;
			bSendData = CyTrue;
			DPINFO(3, "%d,  panVal = %d, tiltVal = %d\r\n", __LINE__, panVal, tiltVal);
		}
#if 1
		else
		{
			panVal   = nPan *250;//һη͵ֵͣ϶Ľ,ȻPTһ
			tiltVal  = nTle *250;
			bSendData = CyTrue;
		}
#endif//
#endif//
//		panVal   = nPan *250;//һη͵ֵͣ϶Ľ,ȻPTһ
//		tiltVal  = nTle *250;
//		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_MIN_REQ:
		panVal = CONFIG_PTZ_PAN_MIN;//-170 * 3600;
		tiltVal = CONFIG_PTZ_TILT_MIN;//-30 * 3600;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_MAX_REQ:
		panVal  = CONFIG_PTZ_PAN_MAX;//170 * 3600;
		tiltVal = CONFIG_PTZ_TILT_MAX;//90 * 3600;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_RES_REQ:
		panVal = 1;
		tiltVal = 1;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_DEF_REQ:
		panVal   = 0;
		tiltVal  = 0;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_SET_CUR_REQ:
		{
			uint8_t byData[] = {0xE2, 0x00, 0x81, 0x01, 0x06, 0x02, 0x10, 0x10, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
			apiRetStatus = CyU3PUsbGetEP0Data(CY_FX_UVC_MAX_PROBE_SETTING_ALIGNED, glEp0Buffer, &readCount);
			if(apiRetStatus == CY_U3P_SUCCESS)
			{
				nPan = ((glEp0Buffer[0]) | (glEp0Buffer[1]<<8) |(glEp0Buffer[2]<<16) | (glEp0Buffer[3]<<24));
				nTle = ((glEp0Buffer[4]) | (glEp0Buffer[5]<<8) |(glEp0Buffer[6]<<16) | (glEp0Buffer[7]<<24));
				DPINFO(3, "%d, nPan = %d, nTle = %d, readCount = %d\r\n", __LINE__, nPan, nTle, readCount);
				nPan = ((nPan + 249) / 250);//3600) * 14.4;
				nTle = ((nTle + 249) / 250);//3600) * 14.4;
				byData[8]  = (nPan & 0xF000) >> 12;
				byData[9]  = (nPan & 0x0F00) >> 8;
				byData[10] = (nPan & 0x00F0) >> 4;
				byData[11] = (nPan & 0x000F);
				byData[12] = (nTle & 0xF000) >> 12;
				byData[13] = (nTle & 0x0F00) >> 8;
				byData[14] = (nTle & 0x00F0) >> 4;
				byData[15] = (nTle & 0x000F);
				datarw_write(byData, sizeof(byData));
//				CyU3PThreadSleep(150);
			}
		}
		break;
	default:
		CyU3PUsbStall (0, CyTrue, CyFalse);
		break;
	}
	if (bSendData)
	{
	 	/* Send the 8-byte PAN and TILT values back to the USB host. */
	    glEp0Buffer[0] = CY_U3P_DWORD_GET_BYTE0 (panVal);
	    glEp0Buffer[1] = CY_U3P_DWORD_GET_BYTE1 (panVal);
	    glEp0Buffer[2] = CY_U3P_DWORD_GET_BYTE2 (panVal);
	    glEp0Buffer[3] = CY_U3P_DWORD_GET_BYTE3 (panVal);
	    glEp0Buffer[4] = CY_U3P_DWORD_GET_BYTE0 (tiltVal);
	    glEp0Buffer[5] = CY_U3P_DWORD_GET_BYTE1 (tiltVal);
	    glEp0Buffer[6] = CY_U3P_DWORD_GET_BYTE2 (tiltVal);
	    glEp0Buffer[7] = CY_U3P_DWORD_GET_BYTE3 (tiltVal);
	    CyU3PUsbSendEP0Data (g_wLength, (uint8_t *)glEp0Buffer);
	}
}
#endif


#endif //CONFIG_PTZ_PAN_MIN

#if defined(CONFIG_PTZ_ZOOM_MIN)
#if defined(CLEAR_ONE)
static void zoom_relative(void)
{
	CyBool_t bSendData = CyFalse;
   	CyU3PReturnStatus_t apiRetStatus = CY_U3P_SUCCESS;
	uint16_t readCount = 0;

	uint8_t bZoom = 0;
	uint8_t bDigitalZoom = 0;
	uint8_t bZoomSpeed = 0;
	switch (g_bRequest)
	{
	case CY_FX_USB_UVC_GET_INFO_REQ:
		glEp0Buffer[0] = 3;                /* GET/SET requests supported for this control */
		CyU3PUsbSendEP0Data (1, (uint8_t *)glEp0Buffer);
		break;
	case CY_FX_USB_UVC_GET_CUR_REQ:
		bZoom = 0;
		bDigitalZoom = 0;
		bZoomSpeed = 3;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_MIN_REQ:
		bZoom = 0;
		bDigitalZoom = 0;
		bZoomSpeed = 0;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_MAX_REQ:
		bZoom = 0;
		bDigitalZoom = 0;
		bZoomSpeed = 3;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_RES_REQ:
		bZoom = 0;
		bDigitalZoom = 0;
		bZoomSpeed = 1;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_DEF_REQ:
		bZoom = 0;
		bDigitalZoom = 0;
		bZoomSpeed = 3;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_SET_CUR_REQ:
		apiRetStatus = CyU3PUsbGetEP0Data (CY_FX_UVC_MAX_PROBE_SETTING_ALIGNED, glEp0Buffer, &readCount);
		if (apiRetStatus == CY_U3P_SUCCESS)
		{
			DPINFO(3, "%d, glEp0Buffer 0=%X, 1=%X, 2=%X\r\n", __LINE__, glEp0Buffer[0], glEp0Buffer[1], glEp0Buffer[2]);

			uint8_t byData[] = {0xE2, 0x00, 0x81, 0x01, 0x04, 0x07, 0x00, 0xFF};
			bZoomSpeed = 0x10;
			if (glEp0Buffer[2] == 0x02)
			{
				byData[6] = 0x02;
				datarw_write(byData, sizeof(byData));
				s_bZoomMove = 1;
				DPINFO(3, "%d, tele dir \r\n", __LINE__);
			}
			else if (glEp0Buffer[2] == 0x03)
			{
				byData[6] = 0x03;
				datarw_write(byData, sizeof(byData));
				s_bZoomMove = 1;
				DPINFO(3, "%d, wide dir \r\n", __LINE__);
			}
			else if (glEp0Buffer[2] == 0 && s_bZoomMove)
			{
				s_bZoomMove = 0;
				byData[6] = 0x00;
				datarw_write(byData, sizeof(byData));
				DPINFO(3, "%d, stop all \r\n", __LINE__);
			}
		}
		break;
	default:
		CyU3PUsbStall (0, CyTrue, CyFalse);
		break;
	}
	if (bSendData)
	{
		/* Send the 8-byte PAN and TILT values back to the USB host. */
		glEp0Buffer[0] = bZoom;//CY_U3P_DWORD_GET_BYTE0 (panVal);
		glEp0Buffer[1] = bDigitalZoom;//CY_U3P_DWORD_GET_BYTE1 (panVal);
		glEp0Buffer[2] = bZoomSpeed;//CY_U3P_DWORD_GET_BYTE2 (panVal);
		CyU3PUsbSendEP0Data(g_wLength, (uint8_t *)glEp0Buffer);
	}
}
#else
static void zoom_relative(void)
{
	CyBool_t bSendData = CyFalse;
   	CyU3PReturnStatus_t apiRetStatus = CY_U3P_SUCCESS;
	uint16_t readCount = 0;
	
	uint8_t bZoom = 0;
	uint8_t bDigitalZoom = 0;
	uint8_t bZoomSpeed = 0;
	switch (g_bRequest)
	{
	case CY_FX_USB_UVC_GET_INFO_REQ:
		glEp0Buffer[0] = 3;                /* GET/SET requests supported for this control */
		CyU3PUsbSendEP0Data (1, (uint8_t *)glEp0Buffer);
		break;
	case CY_FX_USB_UVC_GET_CUR_REQ:
		bZoom = 0;
		bDigitalZoom = 0;
		bZoomSpeed = 3;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_MIN_REQ:
		bZoom = 0;
		bDigitalZoom = 0;
		bZoomSpeed = 0;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_MAX_REQ:
		bZoom = 0;
		bDigitalZoom = 0;
		bZoomSpeed = 3;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_RES_REQ:
		bZoom = 0;
		bDigitalZoom = 0;
		bZoomSpeed = 1;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_DEF_REQ:
		bZoom = 0;
		bDigitalZoom = 0;
		bZoomSpeed = 3;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_SET_CUR_REQ:
		apiRetStatus = CyU3PUsbGetEP0Data (CY_FX_UVC_MAX_PROBE_SETTING_ALIGNED, glEp0Buffer, &readCount);
		if (apiRetStatus == CY_U3P_SUCCESS)
		{
			DPINFO(3, "%d, glEp0Buffer 0=%X, 1=%X, 2=%X\r\n", __LINE__, glEp0Buffer[0], glEp0Buffer[1], glEp0Buffer[2]);

			uint8_t byData[] = {0xE2, 0x00, 0x81, 0x01, 0x04, 0x07, 0x00, 0xFF};
			bZoomSpeed = glEp0Buffer[2];
			if ((glEp0Buffer[0] == 0x02) || (glEp0Buffer[0] == 0x01)) //жʹ֮windowsMAC OS
			{
				byData[6] = 0x02;
				datarw_write(byData, sizeof(byData));
				s_bZoomMove = 1;
				DPINFO(3, "%d, tele dir \r\n", __LINE__);
			}
			else if ((glEp0Buffer[0] == 0x03) || (glEp0Buffer[0] == 0xff)) //жʹ֮windowsMAC OS
			{
				byData[6] = 0x03;
				datarw_write(byData, sizeof(byData));
				s_bZoomMove = 1;
				DPINFO(3, "%d, wide dir \r\n", __LINE__);
			}
			else if ((glEp0Buffer[0] == 0x00) && s_bZoomMove)
			{
				s_bZoomMove = 0;
				byData[6] = 0x00;
				datarw_write(byData, sizeof(byData));
				DPINFO(3, "%d, Zoom stop  \r\n", __LINE__);
			}
		}
		break;
	default:
		CyU3PUsbStall (0, CyTrue, CyFalse);
		break;
	}
	if (bSendData)
	{
		/* Send the 8-byte PAN and TILT values back to the USB host. */
		glEp0Buffer[0] = bZoom;//CY_U3P_DWORD_GET_BYTE0 (panVal);
		glEp0Buffer[1] = bDigitalZoom;//CY_U3P_DWORD_GET_BYTE1 (panVal);
		glEp0Buffer[2] = bZoomSpeed;//CY_U3P_DWORD_GET_BYTE2 (panVal);
		CyU3PUsbSendEP0Data(g_wLength, (uint8_t *)glEp0Buffer);
	}
}
#endif//CLEAR_ONE
static void zoom_absolute(void)
{
	uint16_t zoomVal = 0;
	CyBool_t bSendData = CyFalse;
	uint8_t byData[] = {0xE2, 0x00, 0x81, 0x09, 0x04, 0xa9, 0x01, 0xFF};
	switch (g_bRequest)
	{
	case CY_FX_USB_UVC_GET_INFO_REQ:
		glEp0Buffer[0] = 3;                /* Support GET/SET queries. */
		CyU3PUsbSendEP0Data (1, (uint8_t *)glEp0Buffer);
		break;
	case CY_FX_USB_UVC_GET_CUR_REQ: /* Current zoom control value. 8x 09 04 47 FF*/
		datarw_write(byData, sizeof(byData));
		if(datarw_read(g_byReadBuffer, 11, 2, byData[5], byData[6]))
		{
			zoomVal = (g_byReadBuffer[6] << 12) | (g_byReadBuffer[7] << 8) | (g_byReadBuffer[8] << 4) | g_byReadBuffer[9];
//			DPINFO(3, "%d, zoom g_byReadBuffer[6][7][8][9] = %X %X %X %X\r\n", __LINE__, g_byReadBuffer[6], g_byReadBuffer[7], g_byReadBuffer[8], g_byReadBuffer[9]);
			DPINFO(3, "%d, zoomVal = %d\r\n", __LINE__, zoomVal);
		}
		else
		{
			zoomVal = 0;
		}
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_MIN_REQ: /* Minimum zoom control value. */
		zoomVal = CONFIG_PTZ_ZOOM_MIN;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_MAX_REQ: /* Maximum zoom control value. */
		zoomVal = CONFIG_PTZ_ZOOM_MAX;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_RES_REQ: /* Resolution is one unit. */
		zoomVal = 1;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_GET_DEF_REQ: /* Default zoom setting. */
		zoomVal = 0;
		bSendData = CyTrue;
		break;
	case CY_FX_USB_UVC_SET_CUR_REQ:
		{
			CyU3PReturnStatus_t apiRetStatus = CY_U3P_SUCCESS;
			uint16_t readCount = 0;
			apiRetStatus = CyU3PUsbGetEP0Data(CY_FX_UVC_MAX_PROBE_SETTING_ALIGNED, glEp0Buffer, &readCount);
			if(apiRetStatus == CY_U3P_SUCCESS)
			{
				DPINFO(3, "%d, readCount = %d glEp0Buffer0 = %X 1= %X\r\n", __LINE__, readCount, glEp0Buffer[0], glEp0Buffer[1]);
				uint8_t byData[] = {0xE2, 0x00, 0x81, 0x01, 0x04, 0x47, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
				zoomVal = (glEp0Buffer[0]) | (glEp0Buffer[1] << 8);
				byData[6] = (zoomVal & 0xF000) >> 12;
				byData[7] = (zoomVal & 0x0F00) >> 8;
				byData[8] = (zoomVal & 0x00F0) >> 4;
				byData[9] = (zoomVal & 0x000F);
				datarw_write(byData, sizeof(byData));
			}
		}
		break;
	default:
		CyU3PUsbStall (0, CyTrue, CyFalse);
		break;
	}
	if (bSendData)
	{
		/* Send the 2-byte data in zoomVal back to the USB host. */
	    glEp0Buffer[0] = CY_U3P_GET_LSB (zoomVal);
	    glEp0Buffer[1] = CY_U3P_GET_MSB (zoomVal);
	    CyU3PUsbSendEP0Data (g_wLength, (uint8_t *)glEp0Buffer);
	}
}
#endif//CONFIG_PTZ_ZOOM_MIN
/*
 * Handler for control requests addressed to the UVC Camera Terminal unit.
 */
void UVCHandleCameraTerminalRqts(void)
{
	//uint8_t byData[8] = {0xE2, 0x00, 0x81, 0x01, 0x04, 0x23, 0xee, 0xFF};
	//DPINFO(3, "%d, g_wValue=%X, g_bRequest=%X\r\n", __LINE__, g_wValue, g_bRequest);
    switch (g_wValue)
    {
#if defined(CONFIG_PTZ_PAN_MIN)
    case CY_FX_UVC_CT_PANTILT_RELATIVE_CONTROL:
        pantilt_relative();
    break;

	case CY_FX_UVC_CT_PANTILT_ABSOLUTE_CONTROL:
        pantilt_absolute();
	break;
#endif//CONFIG_PTZ_PAN_MIN

#if defined(CONFIG_PTZ_ZOOM_MIN)
	case CY_FX_UVC_CT_ZOOM_RELATIVE_CONTROL:
		zoom_relative();
	break;

	case CY_FX_UVC_CT_ZOOM_ABSOLUTE_CONTROL:
		zoom_absolute();
    break;
#endif//CONFIG_PTZ_ZOOM_MIN
	default:
		CyU3PUsbStall (0, CyTrue, CyFalse);
	break;
    }
}

void UVCHandleProcessVideoFormat(CyU3PUSBSpeed_t usbSpeed, uint8_t u8Format, uint8_t nFps)
{
	uint8_t byWriteBuf[] = {0xE2, 0x00, 0x81, 0x0A, 0x01, 0x04, 0xFF, 0xFF};
	if (usbSpeed == CY_U3P_SUPER_SPEED) // USB3.0
	{
		if(u8Format == 2)
		{
			// 1080P
			if(nFps == 0x15)			// 30FPS
				byWriteBuf[6] = 0x06;
			else if(nFps == 0xa)		// 60fps
				byWriteBuf[6] = 0x00;
			else if(nFps == 0x40)		// 50fps
				byWriteBuf[6] = 0x01;
			else if(nFps == 0x80)		// 25fps
				byWriteBuf[6] = 0x07;
			else
				byWriteBuf[6] = 0x06;
		}
		else if(u8Format == 1)
		{
			// 720P
			if(nFps == 0x15)			// 30FPS
				byWriteBuf[6] = 0x08;
			else if(nFps == 0xa)		// 60fps
				byWriteBuf[6] = 0x04;
			else if(nFps == 0x40)		// 50fps
				byWriteBuf[6] = 0x05;
			else if(nFps == 0x80)		// 25fps
				byWriteBuf[6] = 0x09;
#if 0
			else if(nFps == 0x2a)
				byWriteBuf[6] = 0x10;   // 15fps
			else
				byWriteBuf[6] = 0x13;   // 10fps
#endif//USB3.0 ȡ 720P15 P10
			else
				byWriteBuf[6] = 0x08; 	//720pĬϷp30
		}
		else if (u8Format == 3)
		{
			byWriteBuf[6] = 0x16;		// 640*480p30pfs
		}
		else if(u8Format == 4)
		{
			byWriteBuf[6] = 0x17;		// 352*288p30pfs
		}
		else if (u8Format == 5)
		{
			byWriteBuf[6] = 0x15;		// 640*360p30pfs
		}
		else if (u8Format == 6)
		{
			byWriteBuf[6] = 0x14;		// 960*540p30pfs
		}
		else if (u8Format == 7)
		{
			byWriteBuf[6] = 0x18;		// 800*600p30pfs
		}
		else
		{
			byWriteBuf[6] = 0x08;		//USB3.0OĬϷ720p30Ϊ˼vydio
		}
	}
	else
	{
		if(u8Format == 2)
		{
			byWriteBuf[6] = 0x11; 		// 720*576p50fps
		}
		else if(u8Format == 3)
		{
			if(nFps == 0x2a)
				byWriteBuf[6] = 0x10;   // 15fps
			else
				byWriteBuf[6] = 0x13;   // 10fps
		}
		else if (u8Format == 1)
		{
			byWriteBuf[6] = 0x12;		// 720*480p60pfs
		}
		else if(u8Format == 4)
		{
			byWriteBuf[6] = 0x15; 		// 640*360p30pfs
		}
		else if (u8Format == 5)
		{
			byWriteBuf[6] = 0x14;		// 960*540p30pfs
		}
		else if (u8Format == 6)
		{
			byWriteBuf[6] = 0x16;		// 640*480p30pfs
		}
		else if (u8Format == 7)
		{
			byWriteBuf[6] = 0x17;		// 352*288p30pfs
		}
		else if (u8Format == 8)
		{
			byWriteBuf[6] = 0x18;		// 800*600p30pfs
		}
		else
			byWriteBuf[6] = 0x14;		// 960*540p30pfs
	}
	byWriteBuf[7] = 0xFF;
	datarw_write(byWriteBuf, sizeof(byWriteBuf));
	DPINFO(3, "%d, set VideoFormat = %X\r\n", __LINE__, byWriteBuf[6]);
}
